@@ -56,6 +56,15 @@ class CreateTransitRouterVbrAttachmentRequest(RpcRequest):
 
 	def set_TransitRouterAttachmentName(self, TransitRouterAttachmentName):  # String
 		self.add_query_param('TransitRouterAttachmentName', TransitRouterAttachmentName)
+	def get_Tags(self): # RepeatList
+		return self.get_query_params().get('Tag')
+
+	def set_Tags(self, Tag):  # RepeatList
+		for depth1 in range(len(Tag)):
+			if Tag[depth1].get('Value') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
+			if Tag[depth1].get('Key') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
 	def get_AutoPublishRouteEnabled(self): # Boolean
 		return self.get_query_params().get('AutoPublishRouteEnabled')
 
