@@ -23,7 +23,7 @@ from aliyunsdkcbn.endpoint import endpoint_data
 class DeleteTransitRouterVpnAttachmentRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Cbn', '2017-09-12', 'DeleteTransitRouterVpnAttachment','cbn')
+		RpcRequest.__init__(self, 'Cbn', '2017-09-12', 'DeleteTransitRouterVpnAttachment')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -66,3 +66,8 @@ class DeleteTransitRouterVpnAttachmentRequest(RpcRequest):
 
 	def set_TransitRouterAttachmentId(self, TransitRouterAttachmentId):  # String
 		self.add_query_param('TransitRouterAttachmentId', TransitRouterAttachmentId)
+	def get_Force(self): # Boolean
+		return self.get_query_params().get('Force')
+
+	def set_Force(self, Force):  # Boolean
+		self.add_query_param('Force', Force)
