@@ -23,58 +23,51 @@ from aliyunsdkcbn.endpoint import endpoint_data
 class DisableCenVbrHealthCheckRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Cbn', '2017-09-12', 'DisableCenVbrHealthCheck','cbn')
+		RpcRequest.__init__(self, 'Cbn', '2017-09-12', 'DisableCenVbrHealthCheck')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_CenId(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_CenId(self): # String
 		return self.get_query_params().get('CenId')
 
-	def set_CenId(self,CenId):
-		self.add_query_param('CenId',CenId)
-
-	def get_VbrInstanceOwnerId(self):
+	def set_CenId(self, CenId):  # String
+		self.add_query_param('CenId', CenId)
+	def get_VbrInstanceOwnerId(self): # Long
 		return self.get_query_params().get('VbrInstanceOwnerId')
 
-	def set_VbrInstanceOwnerId(self,VbrInstanceOwnerId):
-		self.add_query_param('VbrInstanceOwnerId',VbrInstanceOwnerId)
-
-	def get_VbrInstanceRegionId(self):
+	def set_VbrInstanceOwnerId(self, VbrInstanceOwnerId):  # Long
+		self.add_query_param('VbrInstanceOwnerId', VbrInstanceOwnerId)
+	def get_VbrInstanceRegionId(self): # String
 		return self.get_query_params().get('VbrInstanceRegionId')
 
-	def set_VbrInstanceRegionId(self,VbrInstanceRegionId):
-		self.add_query_param('VbrInstanceRegionId',VbrInstanceRegionId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_VbrInstanceRegionId(self, VbrInstanceRegionId):  # String
+		self.add_query_param('VbrInstanceRegionId', VbrInstanceRegionId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_VbrInstanceId(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_VbrInstanceId(self): # String
 		return self.get_query_params().get('VbrInstanceId')
 
-	def set_VbrInstanceId(self,VbrInstanceId):
-		self.add_query_param('VbrInstanceId',VbrInstanceId)
\ No newline at end of file
+	def set_VbrInstanceId(self, VbrInstanceId):  # String
+		self.add_query_param('VbrInstanceId', VbrInstanceId)
